@@ -23,14 +23,17 @@ gofstats<-function(Y)
   
   dyad.dep<- suppressWarnings( cor( c(Y),c(t(Y)) , use="complete.obs") ) 
  
-  E<-Y-mean(Y,na.rm=TRUE) ;  D<-1*(!is.na(E)) ; E[is.na(E)]<-0
-  triad.dep<- sum(diag(E%*%E%*%E))/( sum(diag(D%*%D%*%D)) * sd(c(Y),na.rm=TRUE)^3)
+  E<-Y-mean(Y,na.rm=TRUE)
+  D<-1*(!is.na(E)) ; E[is.na(E)]<-0
+  triad.dep<-c( 
+     sum(diag(E%*%E%*%E))/( sum(diag(D%*%D%*%D))*sd(c(Y),na.rm=TRUE)^3), 
+     sum(diag(E%*%t(E)%*%E))/( sum(diag(D%*%t(D)%*%D))*sd(c(Y),na.rm=TRUE)^3) ) 
 
   gof<-c(sd.rowmean,sd.colmean, dyad.dep , triad.dep ) 
 
   gof[is.na(gof)]<-0 
 
-  names(gof)<-c("sd.rowmean","sd.colmean","dyad.dep","triad.dep")
+  names(gof)<-c("sd.rowmean","sd.colmean","dyad.dep","cycle.dep","trans.dep")
   gof
 }
 
